class KeyModifier:

    def __init__(self, key_name):
        self._key_name = key_name

    def __call__(self, obj):
        return obj[self._key_name]


class KeysModifier:

    def __init__(self, key_names):
        self._key_names = key_names

    def __call__(self, obj):
        return (obj[key_name] for key_name in self._key_names)


from index_by.modifier import index_by_modifier_as_list, index_by_modifier
from index_by.modifiers.attr import AttributeModifier


def index_by_attr(sequence, attr_name, target_index=None):
    return index_by_modifier(
        sequence,
        AttributeModifier(attr_name),
        target_index)


def index_by_attr_as_list(sequence, attr_name, target_index=None):
    return index_by_modifier_as_list(
        sequence,
        AttributeModifier(attr_name),
        target_index)



from setuptools import setup


setup(
    name='index-by',
    version='0.0.1',
    url='https://github.com/twiebe/py-index-by',
    license='BSD',
    author='Thomas Wiebe',
    author_email='code@heimblick.net',
    description='Index objects in a sequence easily',
    long_description=__doc__,
    package_dir={'': 'src'},
    packages=['index_by', 'index_by.modifiers'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



from index_by.modifier import index_by_modifier_as_list, index_by_modifier
from index_by.modifiers.key import KeyModifier


def index_by_key(sequence, key_name, target_index=None):
    return index_by_modifier(
        sequence,
        KeyModifier(key_name),
        target_index)


def index_by_key_as_list(sequence, key_name, target_index=None):
    return index_by_modifier_as_list(
        sequence,
        KeyModifier(key_name),
        target_index)
